<?php

namespace Drupal\hubspot_api_webform\Plugin\Action;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Action\ActionBase;
use Drupal\Core\Session\AccountInterface;

/**
 * Sync a submission to hubspot. HubSpot Webform Handler required.
 *
 * @Action(
 *   id = "hubspot_api_webform_sync_submission_action",
 *   label = @Translation("Sync to Hubspot"),
 *   type = "webform_submission"
 * )
 */
class SyncWebformSubmissionToHubspotAction extends ActionBase {

  /**
   * {@inheritdoc}
   */
  public function execute($entity = NULL) {
    /** @var \Drupal\webform\WebformSubmissionInterface $entity */
    $webform = $entity->getWebform();
    /** @var \Drupal\webform\Plugin\WebformHandlerPluginCollection $handlers */
    $handlers = $webform->getHandlers('hubspot_api_webform_handler');
    foreach ($handlers->getInstanceIds() as $instance_id) {
      /** @var \Drupal\hubspot_api_webform\Plugin\WebformHandler\HubspotWebformHandler $handler */
      $handler = $handlers->get($instance_id);
      $handler->postSave($entity);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function access($object, AccountInterface $account = NULL, $return_as_object = FALSE) {
    /** @var \Drupal\webform\WebformSubmissionInterface $object */
    $webform = $object->getWebform();
    /** @var \Drupal\webform\Plugin\WebformHandlerPluginCollection $handlers */
    $handlers = $webform->getHandlers('hubspot_api_webform_handler');
    $result = AccessResult::allowedIf(!empty($handlers->getInstanceIds()));
    return $return_as_object ? $result : $result->isAllowed();
  }

}
